@@ -44,6 +44,7 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "inspect.equals": Style(),
     "inspect.help": Style(color="cyan"),
     "inspect.doc": Style(dim=True),
+    "live.ellipsis": Style(bold=True, color="red"),
     "logging.keyword": Style(bold=True, color="yellow"),
     "logging.level.notset": Style(dim=True),
     "logging.level.debug": Style(color="green"),
@@ -55,6 +56,8 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "log.time": Style(color="cyan", dim=True),
     "log.message": Style.null(),
     "log.path": Style(dim=True),
+    "repr.ellipsis": Style(color="yellow"),
+    "repr.indent": Style(color="green", dim=True),
     "repr.error": Style(color="red", bold=True),
     "repr.str": Style(color="green", italic=False, bold=False),
     "repr.brace": Style(bold=True),
@@ -113,6 +116,8 @@ DEFAULT_STYLES: Dict[str, Style] = {
     "progress.percentage": Style(color="magenta"),
     "progress.remaining": Style(color="cyan"),
     "progress.data.speed": Style(color="red"),
+    "progress.spinner": Style(color="green"),
+    "status.spinner": Style(color="green"),
 }
 
 MARKDOWN_STYLES = {
